Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(998)

Unified Diff: dart/editor/tools/plugins/com.google.dart.tools.debug.core/src/com/google/dart/tools/debug/core/server/ServerRemoteScriptSourceContainer.java

Issue 322303002: Version 1.5.0-dev.4.6 (Closed) Base URL: http://dart.googlecode.com/svn/trunk/
Patch Set: Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: dart/editor/tools/plugins/com.google.dart.tools.debug.core/src/com/google/dart/tools/debug/core/server/ServerRemoteScriptSourceContainer.java
===================================================================
--- dart/editor/tools/plugins/com.google.dart.tools.debug.core/src/com/google/dart/tools/debug/core/server/ServerRemoteScriptSourceContainer.java (revision 37220)
+++ dart/editor/tools/plugins/com.google.dart.tools.debug.core/src/com/google/dart/tools/debug/core/server/ServerRemoteScriptSourceContainer.java (working copy)
@@ -63,9 +63,9 @@
int libraryId = Integer.parseInt(name.substring(0, index));
// TODO(devoncarew): change the buildin: format to an opaque token into a map; this will
// let us eliminate the call to target.getMainIsolate().
String source = target.getConnection().getScriptSource(
- target.getMainIsolate(),
+ target.getCurrentIsolate(),
libraryId,
url);
@@ -63,9 +63,9 @@
int libraryId = Integer.parseInt(name.substring(0, index));
// TODO(devoncarew): change the buildin: format to an opaque token into a map; this will
- // let us eliminate the call to target.getMainIsolate().
+ // let us eliminate the call to target.getCurrentIsolate().
String source = target.getConnection().getScriptSource(

Powered by Google App Engine
This is Rietveld 408576698